/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.generator.tal.template;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import mir.generator.tal.interfaces.TALExpressionParser;
import mir.generator.tal.interfaces.TALLogger;

/**
 * Template node that is composed of a list of template nodes.
 *
 */
public class CompositeTemplateNode implements TemplateNode {
  private List parts;

  public CompositeTemplateNode() {
    parts = new ArrayList();
  }

  /** {@inheritDoc} */
  public void process(TALExpressionParser aParser, Object aContext, StringBuffer aDestination,
      TALLogger aLogger, Map aTemplateContext, TemplateLibrary aLibrary) throws TemplateProcessingException {
    Iterator i = parts.iterator();

    while (i.hasNext()) {
      ((TemplateNode) i.next()).process(aParser, aContext, aDestination, aLogger, aTemplateContext, aLibrary);
    }
  }

  public String getPlainText() {
    StringBuffer result = new StringBuffer();

    Iterator i = parts.iterator();
    while (i.hasNext()) {
      result.append(((TemplateNode) i.next()).getPlainText());
    }

    return result.toString();
  }

  public boolean isEmpty() {
    return parts.isEmpty();
  }

  /**
   * Adds a <code>TemplateNode</code> at the end of the chain.
   */
  public void appendSubNode(TemplateNode aNode) {
    if (aNode instanceof CompositeTemplateNode) {
      Iterator i = ((CompositeTemplateNode) aNode).parts.iterator();
      while (i.hasNext()) {
        appendSubNode((TemplateNode) i.next());
      }
    }
    else if (aNode instanceof PlainTextTemplateNode &&
             parts.size()>0 &&
             (parts.get(parts.size()-1) instanceof PlainTextTemplateNode)) {

      ((PlainTextTemplateNode) parts.get(parts.size()-1)).appendText(((PlainTextTemplateNode) aNode).getText());
      ((PlainTextTemplateNode) parts.get(parts.size()-1)).appendPlainText(((PlainTextTemplateNode) aNode).getPlainText());
    }
    else {
      parts.add(aNode);
    }
  }

}
