/*
 * Copyright (C) 2001-2006 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.session;

import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;

public interface UploadedFile {
  /**
   * Writes the uploaded content to a file
   */
  public void writeToFile(File aFile) throws SessionExc, SessionFailure;

  /**
   * Writes the uploaded content to a file
   */
  public void writeToStream(OutputStream aStream) throws SessionExc, SessionFailure;

  /**
   * Creates an <code>InputStream</code> to access the uploaded content  
   */
  public InputStream getInputStream() throws SessionExc, SessionFailure;

  /**
   * Return the filename supplied by the uploader if available.
   * <code>null</code> if no filename is available.
   */
  public String getFileName();

  /**
   * Return the field name associated with the uploaded file
   */
  public String getFieldName();

  /**
   * Return the content type (if it's present) of the uploaded file.
   * <code>null</code> if no content type is available. 
   */
  public String getContentType();
}